/* Controller. This object controls the tableView, provides feedback between the data table view and the list of data, and updates the targets accordingly. Controller is a set of DataPoint */

#import <Cocoa/Cocoa.h>
#import "DataPoint.h"
#import "PDFView.h"
#import "MyDocument.h"

@class DataPoint, PDFView, MyDocument;

@interface Controller : NSBrowserCell
{
    MyDocument *documentController;
    NSTableView *tableView; // the table view in which the data will be drawned
    PDFView *plotView; // the PDF view in which the points are to be potted
    NSMutableArray *tableArray; // the array of DataPoint objects
    NSColorWell *colorWell; // the color well to select the point color
    NSColorWell *gradientColorWell; // the colorWell for the gradient
    NSSlider *sizeSlider; // the slider used to set the size of the points
    NSButton *isVisibleButton; // the button used to check if the serie is visible
    NSButton *isLinkedButton; // the button used to check if the serie is linked
    NSButton *gradientButton;
    NSButton *gradientTypeButton;
    BOOL isLinked;
    BOOL hasGradient;
    BOOL gradType;
    NSPopUpButton *shape; //the popUp button used to determine the shape of the serie
    NSColor * color; // the current selected color for the points
    NSColor * gradientColor; // the current selected color for the points
    float factor; // the scale factor
    int isDrawned; // an integer between 0 and 1 determining if the data serie is being drawned
    int selectedShape; // an integer pointing to a selected shape
    int sorting; // either 0 (ascending) or 1 (descending)
    BOOL loadingFromFile;
    NSMutableArray *columnsTitles;
    NSPopUpButton *sortButton; //determines the sorting
}

- (id) init; //init a new object
- (void) setInterface:(NSMutableDictionary *) interfaceDic;// finishes initialization
- (void) updateData:(NSMutableArray *) theData; // updates the data
- (void) sortData; // sorts the data set
- (void) setColumnNames;
- (void) changeColumnNames: (NSMutableArray *) columnNames;
- (NSMutableArray *) columnNames;
- (void) drawData; // sends a message to draw the data
- (void) setTableView: (NSTableView *) theTable; //Indicates to the object which is the table view
- (void) updateGraphicState; // updates the graphic
- (void) removeAllPoints; // remove all points of a serie once an object is destroyed
- (NSMutableArray *) dataArray; //returns the array of data for the serie
- (NSColor *) color; // return the selected color
- (NSColor *) gradientColor; // return the selected gradient color
- (float) factor; // returns the scale factor of the data
- (int) isDrawned; // returns wether the receiver is set to draw or not
- (BOOL) isLinked;
- (BOOL) hasGradient;
- (BOOL) usesIncreasingColumn;
- (int) shape; // return an integer indicating the selected shape for the serie
- (int) sorting; // return 0 for ascending or 1 for descending
- (NSMutableString *) extractTXTData; //extracting data
@end

